@@ -1,7 +1,7 @@
 package App::cpanminus::script::Patch::Blacklist;
 
 our $DATE = '2017-07-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ App::cpanminus::script::Patch::Blacklist - Blacklist modules from being installe
 
 =head1 VERSION
 
-This document describes version 0.002 of App::cpanminus::script::Patch::Blacklist (from Perl distribution App-cpanminus-script-Patch-Blacklist), released on 2017-07-04.
+This document describes version 0.003 of App::cpanminus::script::Patch::Blacklist (from Perl distribution App-cpanminus-script-Patch-Blacklist), released on 2017-07-04.
 
 =head1 SYNOPSIS
 
@@ -82,7 +82,7 @@ In F<~/cpanm-blacklist.conf>:
 
 In the command-line:
 
- % PERL5OPT=-MModule::Load::In::INIT=App::cpanminus::script::Patch::Blacklist cpanm ...
+ % perl -MModule::Load::In::INIT=App::cpanminus::script::Patch::Blacklist `which cpanm` ...
 
 =head1 DESCRIPTION
 
